@@ -2,6 +2,68 @@
 #QueueOvertime supports one breakdown element with multiple element values, 
 #multiple metrics, and single segment
 
+
+
+#' Run a QueueOvertime Report
+#' 
+#' A QueueOvertime report is a report where the only granularity allowed is
+#' time. This report allows for a single report suite, time granularity,
+#' multiple metrics, and a single segment. It is similar to the "Key Metrics"
+#' report or a Custom Event report within the SiteCatalyst interface.
+#' 
+#' 
+#' Because of the Reporting API structure, this function first requests the
+#' report, then checks the reporting queue to see if the report is completed,
+#' and when the report returns as "done" pulls the report from the API. This
+#' checking process will occur up to the specified number of times (default
+#' 120), with a delay between status checks (default 5 seconds). If the report
+#' does not return as "done" after the number of tries have completed, the
+#' function will return an error message.
+#' 
+#' @param reportSuiteID Report Suite ID
+#' @param dateFrom Report Start Date in "YYYY-MM-DD" format
+#' @param dateTo Report End Date in "YYYY-MM-DD" format. Should be less than or
+#' equal to current date if using anomaly detection.
+#' @param metrics One or more metrics
+#' @param dateGranularity Optional. "Day", "Week", "Month", "Quarter" or "Year"
+#' (case-insensitive).  If no granularity specified, a single row of data
+#' returned as sum of metrics for entire time period.
+#' @param segment_id Optional. If no segment_id is specified, metrics will be
+#' reported for all visitors.
+#' @param anomalyDetection Optional. Use value of "1" to get anomaly detection
+#' results. Results only returned by API for 'Day' granularity.
+#' @param currentData Optional. Use value of "1" to get current data results.
+#' Only needed when dateTo is greater than or equal to the current day.
+#' @param maxTries Optional. Provide integer value for the max number of API
+#' attempts you want to try retrieve the report before function errors out.
+#' Defaults to 120.
+#' @param waitTime Optional. Provide integer value for the number of seconds
+#' between tries to API to try retrieve the report. Defaults to 5 seconds.
+#' @return Data Frame
+#' @seealso \code{\link{GetAvailableMetrics}} \cr \code{\link{GetSegments}}
+#' @keywords QueueOvertime
+#' @examples
+#' 
+#' \dontrun{
+#' 
+#' #Daily granularity for Loyal_Visitors segment (all arguments used)
+#' loyal_visitors_feb_daily <- 
+#' QueueOvertime("keystonerandy", "2013-02-01", "2013-07-28",
+#' metrics = c("pageviews", "visits", "event2"), "day", "Loyal_Visitors", "1")
+#' 
+#' 
+#' #No granularity using empty string in dateGranularity position
+#' loyal_visitors_feb_overall <- 
+#' QueueOvertime("keystonerandy", "2013-02-01", "2013-02-28",
+#' metrics = c("pageviews", "visits", "event2"), "", "Loyal_Visitors")
+#' 
+#' 
+#' #Minimum number of arguments, single row containing sum of pageviews
+#' pageviews_feb <- 
+#' QueueOvertime("keystonerandy", "2013-02-01", "2013-02-28", "pageviews")
+#'    }
+#' 
+#' @export QueueOvertime
 QueueOvertime <- function(reportSuiteID, dateFrom, dateTo, metrics, dateGranularity="", segment_id="", anomalyDetection="", currentData="", maxTries= 120, waitTime= 5) {
 
   if(anomalyDetection == "1" & dateGranularity!="day") {
@@ -42,7 +104,7 @@ queue_resp <- content(json_queue)
 #If response returns an error, return error message. Else, continue with
 #capturing report ID
 if(queue_resp[1] != "queued" ) {
-  stop("Error: Likely a syntax error or missing required argument to QueueOvertime function")
+  stop(sprintf("API %s : %s", queue_resp$status, queue_resp$statusMsg))
 } else {
   reportID <- queue_resp[[3]] 
 }
@@ -90,10 +152,12 @@ rows_df <- cbind(rows_df, segment=result[[5]]$segment_id) #add segment to df
 
 counts <- lapply(data, "[[", "counts") # Just the "counts" column
 counts_df <- ldply(counts, quickdf) # counts as DF
-counts_df <- as.data.frame(apply(counts_df, MARGIN=2, FUN= function(x) as.numeric(x))) #convert to numeric
-  
 names(counts_df) <- lapply(result[[5]]$metrics, "[[", "id") #assign names to counts_df
 
+counts_df <- as.data.frame(lapply(counts_df, FUN= function(x) as.numeric(x))) #convert to numeric
+
+
+
 #Parse anomalyDetection if requested  
 
 if(anomalyDetection == "1" & dateGranularity == "day") {
@@ -113,10 +177,14 @@ if(anomalyDetection == "1" & dateGranularity == "day") {
   lb_df <- as.data.frame(apply(lb_df, MARGIN=2, FUN= function(x) as.numeric(x))) #convert to numeric
   names(lb_df) <- lapply(lapply(result[[5]]$metrics, "[[", "id"), function(x) paste(x, "_lower", sep=""))
   
-  return(cbind(rows_df, counts_df, ub_df, forecasts_df, lb_df)) #return after anomaly parsing
+  end_result <- cbind(rows_df, counts_df, ub_df, forecasts_df, lb_df)
+  
+  return(end_result) #return after anomaly parsing
 } #End parsing anomalyDetection
 
-return(cbind(rows_df, counts_df)) #append rows info with counts if not anomaly parsing
+end_result <- cbind(rows_df, counts_df)
+
+return(end_result) #append rows info with counts if not anomaly parsing
 
 } #End function bracket
 
